@@ -4,8 +4,7 @@
 
 ;; Author: Milan Glacier <dev@milanglacier.com>
 ;; Maintainer: Milan Glacier <dev@milanglacier.com>
-;; Package-Version: 0.7.1
-;; Package-Revision: v0.7.1-0-g7b34bf0f0334
+;; Version: 0.7.1
 ;; URL: https://github.com/milanglacier/minuet-ai.el
 ;; Package-Requires: ((emacs "29") (plz "0.9") (dash "2.19.1"))
 
@@ -540,6 +539,18 @@ Return non-nil when the completion was preserved or updated."
               (total (length suggestions))
               (index (mod (or index 0) total))
               (suggestion (nth index suggestions))
+              ;; Adjust the suggestion text displayed in the overlay
+              ;; by replacing empty lines with a space. This ensures
+              ;; that when the current line is empty, the overlay text
+              ;; is correctly positioned after the cursor rather than
+              ;; before it.
+              (overlay-text (replace-regexp-in-string "^$" " " suggestion))
+              (overlay-text (propertize
+                             (format "%s%s"
+                                     overlay-text
+                                     (if (= total minuet-n-completions 1) ""
+                                       (format " (%d/%d)" (1+ index) total)))
+                             'face 'minuet-suggestion-face))
               ;; 'Display' is used when not at the end-of-line to
               ;; ensure proper overlay positioning. Other methods,
               ;; such as `after-string' or `before-string', fail to
@@ -561,16 +572,9 @@ Return non-nil when the completion was preserved or updated."
     ;; HACK: Adapted from copilot.el We add a 'cursor text property to the
     ;; first character of the suggestion to simulate the visual effect of
     ;; placing the overlay after the cursor
-    (put-text-property 0 1 'cursor t suggestion)
+    (put-text-property 0 1 'cursor t overlay-text)
     (overlay-put ov ov-method
-                 (concat
-                  (propertize
-                   (format "%s%s"
-                           suggestion
-                           (if (= total minuet-n-completions 1) ""
-                             (format " (%d/%d)" (1+ index) total)))
-                   'face 'minuet-suggestion-face)
-                  offset-char))
+                 (concat overlay-text offset-char))
     (overlay-put ov 'minuet t)
     (setq minuet--current-overlay ov)
     (minuet-active-mode 1)))
@@ -579,22 +583,22 @@ Return non-nil when the completion was preserved or updated."
 (defun minuet-next-suggestion ()
   "Cycle to next suggestion."
   (interactive)
-  (if (and minuet--current-suggestions
-           minuet--current-overlay)
-      (let ((next-index (mod (1+ minuet--current-suggestion-index)
-                             (length minuet--current-suggestions))))
-        (minuet--display-suggestion minuet--current-suggestions next-index))
+  (if-let* ((suggestions minuet--current-suggestions)
+            (_ minuet--current-overlay)
+            (next-index (mod (1+ minuet--current-suggestion-index)
+                             (length suggestions))))
+      (minuet--display-suggestion suggestions next-index)
     (minuet-show-suggestion)))
 
 ;;;###autoload
 (defun minuet-previous-suggestion ()
   "Cycle to previous suggestion."
   (interactive)
-  (if (and minuet--current-suggestions
-           minuet--current-overlay)
-      (let ((prev-index (mod (1- minuet--current-suggestion-index)
-                             (length minuet--current-suggestions))))
-        (minuet--display-suggestion minuet--current-suggestions prev-index))
+  (if-let* ((suggestions minuet--current-suggestions)
+            (_ minuet--current-overlay)
+            (prev-index (mod (1- minuet--current-suggestion-index)
+                             (length suggestions))))
+      (minuet--display-suggestion suggestions prev-index)
     (minuet-show-suggestion)))
 
 ;;;###autoload
@@ -756,7 +760,6 @@ CONTEXT is a plist with :before-cursor and :after-cursor fields.
 Returns the filtered item after trimming overlapping parts."
   (when (null item)
     (cl-return-from minuet--filter-text nil))
-
   (when (null context)
     (cl-return-from minuet--filter-text item))
 
@@ -765,27 +768,22 @@ Returns the filtered item after trimming overlapping parts."
   (let* ((before-cursor (plist-get context :before-cursor))
          (after-cursor (plist-get context :after-cursor))
          (filtered-item item))
-
     ;; Filter against before-cursor context (trim from prefix)
-    (when (and before-cursor
-               (> minuet-before-cursor-filter-length 0))
-      (setq before-cursor (string-trim before-cursor))
-      (let* ((match (minuet-find-longest-match filtered-item before-cursor)))
-        (when (and match
-                   (not (string-empty-p match))
-                   (>= (length match) minuet-before-cursor-filter-length))
-          (setq filtered-item (substring filtered-item (length match))))))
-
+    (when-let* ((before-cursor before-cursor)
+                (should-filter (> minuet-before-cursor-filter-length 0))
+                (before-cursor (string-trim before-cursor))
+                (match (minuet-find-longest-match filtered-item before-cursor))
+                (should-filter (and (not (string-empty-p match))
+                                    (>= (length match) minuet-before-cursor-filter-length))))
+      (setq filtered-item (substring filtered-item (length match))))
     ;; Filter against after-cursor context (trim from suffix)
-    (when (and after-cursor
-               (> minuet-after-cursor-filter-length 0))
-      (setq after-cursor (string-trim after-cursor))
-      (let* ((match (minuet-find-longest-match after-cursor filtered-item)))
-        (when (and match
-                   (not (string-empty-p match))
-                   (>= (length match) minuet-after-cursor-filter-length))
-          (setq filtered-item (substring filtered-item 0 (- (length filtered-item) (length match)))))))
-
+    (when-let* ((after-cursor after-cursor)
+                (should-filter (> minuet-after-cursor-filter-length 0))
+                (after-cursor (string-trim after-cursor))
+                (match (minuet-find-longest-match after-cursor filtered-item))
+                (should-filter (and (not (string-empty-p match))
+                                    (>= (length match) minuet-after-cursor-filter-length))))
+      (setq filtered-item (substring filtered-item 0 (- (length filtered-item) (length match)))))
     filtered-item))
 
 (cl-defun minuet-find-longest-match (a b)
@@ -825,10 +823,10 @@ The filter sequence is obtained from CONTEXT."
                            (replace-regexp-in-string "^data: " "" line)
                            :object-type 'plist :array-type 'list)))
                   (text (ignore-errors
-                          (funcall get-text-fn json))))
-        (when (and (stringp text)
-                   (not (equal text "")))
-          (push text result))))
+                          (funcall get-text-fn json)))
+                  (text-not-empty (and (stringp text)
+                                       (not (string= text "")))))
+        (push text result)))
     (setq result (apply #'concat (nreverse result)))
     (if (equal result "")
         (progn
@@ -891,12 +889,11 @@ used to accumulate text output from a process.  After execution,
 (defun minuet-accept-suggestion ()
   "Accept the current overlay suggestion."
   (interactive)
-  (when (and minuet--current-suggestions
-             minuet--current-overlay)
-    (let ((suggestion (nth minuet--current-suggestion-index
-                           minuet--current-suggestions)))
-      (minuet--cleanup-suggestion)
-      (insert suggestion))))
+  (when-let* ((suggestions minuet--current-suggestions)
+              (_ minuet--current-overlay)
+              (suggestion (nth minuet--current-suggestion-index suggestions)))
+    (minuet--cleanup-suggestion)
+    (insert suggestion)))
 
 ;;;###autoload
 (defun minuet-dismiss-suggestion ()
